@@ -122,6 +122,7 @@ class MySQL_Session
 	private:
 	//int handler_ret;
 	void handler___status_CONNECTING_CLIENT___STATE_SERVER_HANDSHAKE(PtrSize_t *, bool *);
+	void handler___status_CONNECTING_CLIENT___STATE_SERVER_HANDSHAKE_WrongCredentials(PtrSize_t *, bool *);
 
 //	void handler___status_CHANGING_USER_CLIENT___STATE_CLIENT_HANDSHAKE(PtrSize_t *, bool *);
 
@@ -202,7 +203,9 @@ class MySQL_Session
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_QUERY___create_mirror_session();
 	int handler_again___status_PINGING_SERVER();
 	int handler_again___status_RESETTING_CONNECTION();
+	bool handler_again___status_SHOW_WARNINGS(MySQL_Data_Stream *, bool);
 	void handler_again___new_thread_to_kill_connection();
+	void handler_KillConnectionIfNeeded();
 
 	bool handler_again___verify_init_connect();
 	bool handler_again___verify_ldap_user_variable();
@@ -210,6 +213,7 @@ class MySQL_Session
 	bool handler_again___verify_backend_session_track_gtids();
 	bool handler_again___verify_backend_multi_statement();
 	bool handler_again___verify_backend_user_schema();
+	bool handler_again___verify_multiple_variables(MySQL_Connection *);
 	bool handler_again___status_SETTING_INIT_CONNECT(int *);
 	bool handler_again___status_SETTING_LDAP_USER_VARIABLE(int *);
 	bool handler_again___status_SETTING_SQL_MODE(int *);
@@ -221,6 +225,7 @@ class MySQL_Session
 	bool handler_again___status_CHANGING_AUTOCOMMIT(int *);
 	bool handler_again___status_SETTING_MULTI_STMT(int *_rc);
 	bool handler_again___multiple_statuses(int *rc);
+
 	void init();
 	void reset();
 	void add_ldap_comment_to_pkt(PtrSize_t *);
@@ -229,7 +234,17 @@ class MySQL_Session
 	 *  performing any processing on received client packets.
 	 */
 	void housekeeping_before_pkts();
+
 	int get_pkts_from_client(bool&, PtrSize_t&);
+
+	// GPFC_ functions are subfunctions of get_pkts_from_client()
+	int GPFC_Statuses2(bool&, PtrSize_t&);
+	void GPFC_DetectedMultiPacket_SetDDS();
+	int GPFC_WaitingClientData_FastForwardSession(PtrSize_t&);
+	void GPFC_PreparedStatements(PtrSize_t&, unsigned char);
+	void GPFC_Replication_SwitchToFastForward(PtrSize_t&, unsigned char);
+	bool GPFC_QueryUSE(PtrSize_t&, int&);
+
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_STMT_RESET(PtrSize_t&);
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_STMT_CLOSE(PtrSize_t&);
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_STMT_SEND_LONG_DATA(PtrSize_t&);
@@ -249,6 +264,7 @@ class MySQL_Session
 	int RunQuery(MySQL_Data_Stream *myds, MySQL_Connection *myconn);
 	void handler___status_WAITING_CLIENT_DATA();
 	void handler_rc0_Process_GTID(MySQL_Connection *myconn);
+	void handler_rc0_RefreshActiveTransactions(MySQL_Connection* myconn);
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_INIT_DB_replace_CLICKHOUSE(PtrSize_t& pkt);
 	void handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_QUERY___not_mysql(PtrSize_t& pkt);
 	bool handler___status_WAITING_CLIENT_DATA___STATE_SLEEP___MYSQL_COM_QUERY_detect_SQLi();
