@@ -15,6 +15,8 @@
 
 #include "ProxySQL_RESTAPI_Server.hpp"
 
+#include "proxysql_typedefs.h"
+
 typedef struct { uint32_t hash; uint32_t key; } t_symstruct;
 class ProxySQL_Config;
 class ProxySQL_Restapi;
@@ -338,6 +340,18 @@ class ProxySQL_Admin {
 	void flush_mysql_variables___runtime_to_database(SQLite3DB *db, bool replace, bool del, bool onlyifempty, bool runtime=false, bool use_lock=true);
 	void flush_mysql_variables___database_to_runtime(SQLite3DB *db, bool replace, const std::string& checksum = "", const time_t epoch = 0);
 
+	void flush_GENERIC_variables__checksum__database_to_runtime(const std::string& modname, const std::string& checksum, const time_t epoch);
+	bool flush_GENERIC_variables__retrieve__database_to_runtime(const std::string& modname, char* &error, int& cols, int& affected_rows, SQLite3_result* &resultset);
+	void flush_GENERIC_variables__process__database_to_runtime(
+		const std::string& modname, SQLite3DB *db, SQLite3_result* resultset,
+		const bool& lock, const bool& replace,
+		const std::unordered_set<std::string>& variables_read_only,
+		const std::unordered_set<std::string>& variables_to_delete_silently,
+		const std::unordered_set<std::string>& variables_deprecated,
+		const std::unordered_set<std::string>& variables_special_values,
+		std::function<void(const std::string&, const char *, SQLite3DB *)> special_variable_action = nullptr
+	);
+
 	char **get_variables_list();
 	bool set_variable(char *name, char *value, bool lock = true);
 	void flush_admin_variables___database_to_runtime(SQLite3DB *db, bool replace, const std::string& checksum = "", const time_t epoch = 0, bool lock = true);
@@ -394,6 +408,8 @@ class ProxySQL_Admin {
 	void public_add_active_users(enum cred_username_type usertype, char *user=NULL) {
 		__add_active_users(usertype, user);
 	}
+	// @brief True if all ProxySQL modules have been already started. End of 'phase3'.
+	bool all_modules_started;
 	ProxySQL_Admin();
 	~ProxySQL_Admin();
 	SQLite3DB *admindb;	// in memory
@@ -416,6 +432,18 @@ class ProxySQL_Admin {
 	 */
 	bool init(const bootstrap_info_t& bootstrap_info);
 	void init_ldap();
+	/** @brief Initializes the HTTP server. For safety should be called after 'phase3'. */
+	void init_http_server();
+	/**
+	 * @brief Loads the HTTP server config to runtime if all modules are ready, no-op otherwise.
+	 * @details Modules ready when 'all_modules_started=true'. See 'all_modules_started'.
+	 */
+	void load_http_server();
+	/**
+	 * @brief Loads the RESTAPI server config to runtime if all modules are ready, no-op otherwise.
+	 * @details Modules ready when 'all_modules_started=true'. See 'all_modules_started'.
+	 */
+	void load_restapi_server();
 	bool get_read_only() { return variables.admin_read_only; }
 	bool set_read_only(bool ro) { variables.admin_read_only=ro; return variables.admin_read_only; }
 	bool has_variable(const char *name);
