@@ -71,21 +71,28 @@ void SetParser::set_query(const std::string& nq) {
 #define VAR_VALUE_P1 "(" VAR_VALUE_P1_1 VAR_VALUE_P1_2 VAR_VALUE_P1_3 VAR_VALUE_P1_4 VAR_VALUE_P1_5 VAR_VALUE_P1_6 ")"
 
 std::map<std::string,std::vector<std::string>> SetParser::parse1() {
-
+#ifdef DEBUG
 	proxy_debug(PROXY_DEBUG_MYSQL_QUERY_PROCESSOR, 4, "Parsing query %s\n", query.c_str());
+#endif // DEBUG
 	re2::RE2::Options *opt2=new re2::RE2::Options(RE2::Quiet);
 	opt2->set_case_sensitive(false);
 	opt2->set_longest_match(false);
 
 	re2::RE2 re0("^\\s*SET\\s+", *opt2);
 	re2::RE2::Replace(&query, re0, "");
+	re2::RE2 re1("(\\s|;)+$", *opt2); // remove trailing spaces and semicolon
+	re2::RE2::Replace(&query, re1, "");
 
 	std::map<std::string,std::vector<std::string>> result;
 
 	const std::string pattern="(?:" NAMES SPACES QUOTES NAME_VALUE QUOTES "(?: +COLLATE +" QUOTES NAME_VALUE QUOTES "|)" "|" SESSION_P1 VAR_P1 SPACES "(?:|:)=" SPACES QUOTES VAR_VALUE_P1 QUOTES ") *,? *";
+#ifdef DEBUG
 VALGRIND_DISABLE_ERROR_REPORTING;
+#endif // DEBUG
 	re2::RE2 re(pattern, *opt2);
+#ifdef DEBUG
 VALGRIND_ENABLE_ERROR_REPORTING;
+#endif // DEBUG
 	std::string var;
 	std::string value1, value2, value3, value4, value5;
 	re2::StringPiece input(query);
@@ -176,12 +183,32 @@ void SetParser::generateRE_parse1v2() {
 
 	string vp = "NULL"; // NULL
 	var_patterns.push_back(vp);
-	vp = "\\w+"; // single word
-	var_patterns.push_back(vp);
-	for (auto it = quote_symbol.begin(); it != quote_symbol.end(); it++) {
-		string s = *it + vp + *it;
-		var_patterns.push_back(s); // add with quote
+	//vp = "\\w+"; // single word
+	//var_patterns.push_back(vp);
+	{
+		string vp0 = "(?:\\w|\\d)+"; // single word with letters and digits , for example utf8mb4 and latin1
+	//var_patterns.push_back(vp);
+/*
+		string vp1 = "(?:" + vp0 + "(?:," + vp0 + ")*)"; // multiple words (letters and digits) separated by commas WITHOUT any spaces between words . Used also for sql_mode , example: ONLY_FULL_GROUP_BY,NO_ZERO_IN_DATE,NO_ZERO_DATE,ERROR_FOR_DIVISION_BY_ZERO
+		//var_patterns.push_back(vp1); // do NOT add without quote
+		for (auto it = quote_symbol.begin(); it != quote_symbol.end(); it++) {
+			string s = *it + vp1 + *it;
+			var_patterns.push_back(s); // add with quote
+		}
+*/
+		string vp2 = "(?:" + vp0 + "(?:-" + vp0 + ")*)"; // multiple words (letters and digits) separated by dash, WITHOUT any spaces between words . Used also for transaction isolation
+		var_patterns.push_back(vp2);
+		for (auto it = quote_symbol.begin(); it != quote_symbol.end(); it++) {
+			string s = *it + vp2 + *it;
+			var_patterns.push_back(s); // add with quote
+		}
 	}
+	//vp = "(?:\\w|\\d)+(?:-|\\w|\\d+)*"; // multiple words (letters and digits) separated by dash, WITHOUT any spaces between words . Used ialso for transaction isolation
+	//var_patterns.push_back(vp);
+//	for (auto it = quote_symbol.begin(); it != quote_symbol.end(); it++) {
+//		string s = *it + vp + *it;
+//		var_patterns.push_back(s); // add with quote
+//	}
 
 	vp = "\\w+(?:,\\w+)+"; // multiple words separated by commas, WITHOUT any spaces between words
 	// NOTE: we do not use multiple words without quotes
@@ -267,9 +294,10 @@ void SetParser::generateRE_parse1v2() {
 		var_value += s;
 	}
 	var_value += ")";
-	
 
+#ifdef DEBUG
 	proxy_debug(PROXY_DEBUG_MYSQL_QUERY_PROCESSOR, 4, "Parsing query %s\n", query.c_str());
+#endif // DEBUG
 	parse1v2_opt2 = new re2::RE2::Options(RE2::Quiet);
 	parse1v2_opt2->set_case_sensitive(false);
 	parse1v2_opt2->set_longest_match(false);
@@ -317,7 +345,9 @@ void SetParser::generateRE_parse1v2() {
 	//const std::string pattern="(?:" NAMES SPACES QUOTES NAME_VALUE QUOTES "(?: +COLLATE +" QUOTES NAME_VALUE QUOTES "|)" "|" SESSION_P1 VAR_P1 SPACES "(?:|:)=" SPACES QUOTES VAR_VALUE_P1 QUOTES ") *,? *";
 	const std::string pattern="(?:" NAMES SPACES + name_value + "(?: +COLLATE +" + name_value + "|)" "|" + var_1 + SPACES "(?:|:)=" SPACES + var_value + ") *,? *";
 	//const std::string pattern=var_1 + SPACES "(?:|:)=" SPACES + var_value;
+#ifdef DEBUG
 VALGRIND_DISABLE_ERROR_REPORTING;
+#endif // DEBUG
 #ifdef PARSERDEBUG
 	if (verbosity > 0) {
 		cout << pattern << endl;
@@ -339,7 +369,12 @@ std::map<std::string,std::vector<std::string>> SetParser::parse1v2() {
 
 	re2::RE2 re0("^\\s*SET\\s+", *parse1v2_opt2);
 	re2::RE2::Replace(&query, re0, "");
+	re2::RE2 re1("(\\s|;)+$", *parse1v2_opt2); // remove trailing spaces and semicolon
+	re2::RE2::Replace(&query, re1, "");
+
+#ifdef DEBUG
 VALGRIND_ENABLE_ERROR_REPORTING;
+#endif // DEBUG
 	std::string var;
 	std::string value1, value2, value3, value4, value5;
 	re2::StringPiece input(query);
@@ -361,6 +396,7 @@ VALGRIND_ENABLE_ERROR_REPORTING;
 			}
 		} else if (value4 != "") {
 			// VARIABLE
+			remove_quotes(value4);
 			if (strcasecmp("transaction_isolation", value4.c_str()) == 0) {
 				value4 = "tx_isolation";
 			} else if (strcasecmp("transaction_read_only", value4.c_str()) == 0) {
@@ -394,7 +430,9 @@ VALGRIND_ENABLE_ERROR_REPORTING;
 
 std::map<std::string,std::vector<std::string>> SetParser::parse2() {
 
+#ifdef DEBUG
 	proxy_debug(PROXY_DEBUG_MYSQL_QUERY_PROCESSOR, 4, "Parsing query %s\n", query.c_str());
+#endif // DEBUG
 	re2::RE2::Options *opt2=new re2::RE2::Options(RE2::Quiet);
 	opt2->set_case_sensitive(false);
 	opt2->set_longest_match(false);
@@ -445,7 +483,9 @@ std::map<std::string,std::vector<std::string>> SetParser::parse2() {
 }
 
 std::string SetParser::parse_character_set() {
+#ifdef DEBUG
 	proxy_debug(PROXY_DEBUG_MYSQL_QUERY_PROCESSOR, 4, "Parsing query %s\n", query.c_str());
+#endif // DEBUG
 	re2::RE2::Options *opt2=new re2::RE2::Options(RE2::Quiet);
 	opt2->set_case_sensitive(false);
 	opt2->set_longest_match(false);
