@@ -409,7 +409,7 @@ static volatile int load_;
 //#else
 //const char *malloc_conf = "xmalloc:true,lg_tcache_max:16,purge:decay";
 #ifndef __FreeBSD__
-const char *malloc_conf = "xmalloc:true,lg_tcache_max:16,prof:true,prof_leak:true,lg_prof_sample:20,lg_prof_interval:30,prof_active:false";
+const char *malloc_conf = "xmalloc:true,lg_tcache_max:16,prof:true,prof_accum:true,prof_leak:true,lg_prof_sample:20,lg_prof_interval:30,prof_active:false";
 #endif
 //#endif /* DEBUG */
 //const char *malloc_conf = "prof_leak:true,lg_prof_sample:0,prof_final:true,xmalloc:true,lg_tcache_max:16";
@@ -1145,7 +1145,6 @@ void ProxySQL_Main_init_phase3___start_all() {
 		GloAdmin->init_mysql_servers();
 		GloAdmin->init_proxysql_servers();
 		GloAdmin->load_scheduler_to_runtime();
-		GloAdmin->proxysql_restapi().load_restapi_to_runtime();
 #ifdef DEBUG
 		std::cerr << "Main phase3 : GloAdmin initialized in ";
 #endif
@@ -1217,6 +1216,17 @@ void ProxySQL_Main_init_phase3___start_all() {
 	if (GloMyLdapAuth) {
 		GloAdmin->init_ldap_variables();
 	}
+
+	// HTTP Server should be initialized after other modules. See #4510
+	GloAdmin->init_http_server();
+	GloAdmin->proxysql_restapi().load_restapi_to_runtime();
+
+	// Signal ProxySQL_Admin that all modules have been started
+	GloAdmin->all_modules_started = true;
+
+	// Load the config not previously loaded for these modules
+	GloAdmin->load_http_server();
+	GloAdmin->load_restapi_server();
 }
 
 
@@ -1859,7 +1869,7 @@ void handleProcessRestart() {
 				// Calculate wait time using exponential backoff
 				int waitTime = 1 << restartAttempts;
 				parent_open_error_log();
-				proxy_info("ProxySQL exited after only %d seconds , below the %d seconds threshold. Restarting attempt %d\n", elapsed_seconds, EXECUTION_THRESHOLD, restartAttempts);
+				proxy_info("ProxySQL exited after only %ld seconds , below the %d seconds threshold. Restarting attempt %d\n", elapsed_seconds, EXECUTION_THRESHOLD, restartAttempts);
 				proxy_info("Angel process is waiting %d seconds before starting a new ProxySQL process\n", waitTime);
 				parent_close_error_log();
 
@@ -1902,7 +1912,61 @@ void handleProcessRestart() {
 	} while (pid > 0);
 }
 
+#ifndef NOJEM
+int print_jemalloc_conf() {
+	int rc = 0;
+
+	bool xmalloc = 0;
+	bool prof_accum = 0;
+	bool prof_leak = 0;
+
+	size_t lg_cache_max = 0;
+	size_t lg_prof_sample = 0;
+	size_t lg_prof_interval = 0;
+
+	size_t bool_sz = sizeof(bool);
+	size_t size_sz = sizeof(size_t);
+	size_t ssize_sz = sizeof(ssize_t);
+
+	rc = mallctl("config.xmalloc", &xmalloc, &bool_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'config.xmalloc' with error %d", rc); return rc; }
+
+	rc = mallctl("opt.lg_tcache_max", &lg_cache_max, &size_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'opt.lg_tcache_max' with error %d", rc);  return rc; }
+
+	rc = mallctl("opt.prof_accum", &prof_accum, &bool_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'opt.prof_accum' with error %d", rc); return rc; }
+
+	rc = mallctl("opt.prof_leak", &prof_leak, &bool_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'opt.prof_leak' with error %d", rc);  return rc; }
+
+	rc = mallctl("opt.lg_prof_sample", &lg_prof_sample, &size_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'opt.lg_prof_sample' with error %d", rc);  return rc; }
+
+	rc = mallctl("opt.lg_prof_interval", &lg_prof_interval, &ssize_sz, NULL, 0);
+	if (rc) { proxy_error("Failed to fetch 'opt.lg_prof_interval' with error %d", rc);  return rc; }
+
+	proxy_info(
+		"Using jemalloc with MALLOC_CONF:"
+			" config.xmalloc:%d, lg_tcache_max:%lu, opt.prof_accum:%d, opt.prof_leak:%d,"
+			" opt.lg_prof_sample:%lu, opt.lg_prof_interval:%lu, rc:%d\n",
+		xmalloc, lg_cache_max, prof_accum, prof_leak, lg_prof_sample, lg_prof_interval, rc
+	);
+
+	return 0;
+}
+#else
+int print_jemalloc_conf() {
+	return 0;
+}
+#endif
+
 int main(int argc, const char * argv[]) {
+	// Output current jemalloc conf; no action taken when disabled
+	{
+		int rc = print_jemalloc_conf();
+		if (rc) { exit(EXIT_FAILURE); }
+	}
 
 	{
 		MYSQL *my = mysql_init(NULL);
