@@ -28,8 +28,8 @@
 #include <iostream>
 
 #include <unistd.h>
-#include <mysql.h>
-#include <mysql/mysqld_error.h>
+#include "mysql.h"
+#include "mysqld_error.h"
 
 #include "json.hpp"
 
