@@ -11,24 +11,66 @@
  *      over time. I.e. connections are not getting destroyed due to not being kept alive.
  *   3. Perform a query per each created connection exahusting the backend connections while checking for
  *      any error reported by the client due to broken connections.
+ *
+ *   Backend Connection Pinging Algorithm:
+ *   ====================================
+ *
+ *   The algorithm used for pinging backend connections is simple:
+ *
+ *   1. Pinging is done for 'idle_session' in batches of SESSIONS_FOR_CONNECTIONS_HANDLER.
+ *   2. The pinging interval is determined by 'ping_interval_server_msec'.
+ *   3. Oldest sessions are always selected first for pinging.
+ *
+ *   With this approach, it should be possible to ping a very large number of backend connections before
+ *   losing them due to inactivity (wait_timeout), this will be defined by:
+ *
+ *   ```
+ *   (NUM_THREADS * SESSIONS_FOR_CONNECTIONS_HANDLER)*floor((MYSQL_wait_timeout-1)/ping_interval_server_msec)
+ *   ```
+ *
+ *   This means that, for example, for a config like: `num_threads=4,wait_timeout=60,batch_size=64`, we can
+ *   expect: `15104` connections. Of course, this suggests that this algorithm wont have any issues holding a
+ *   healthy connection pool of any size when using real `wait_timeout` values.
+ *
+ *   Algorithm - Special Cases:
+ *   =========================
+ *
+ *   This algorithm has a expected behavior that might seems unexpected when pushing the limits of the
+ *   connections that are being maintained; like we can accidentally do in this test. If the number of
+ *   connections being maintained exceeds the number that can be pinged within the `MySQL_wait_timeout`
+ *   interval, this will cause a cascading effect, that will result in extra connections timing out. The
+ *   number of connections from the connection pool that will timeout will be proportional to the fraction of
+ *   the batch (NUM_THREADS*SESSIONS_FOR_CONNECTIONS_HANDLER) filled with connections that exceeded the
+ *   interval processing capacity.
+ *
+ *   If for example, the number of connections exceeded the ones that can be maintained by 50% of the batching
+ *   interval, for the case of 4 threads, this will be 128 connections, then 50% of the connection pool will
+ *   be lost due to this cascading effect. Elaborating a little bit further, when the number of connections
+ *   being maintained exceeds the number of connections that can be pinged, the connections exceeding the
+ *   interval capabilities will timeout, since these connections will be the oldest, they will be the first to
+ *   be selected for the next interval. This will shift all subsequent batching intervals by this number of
+ *   connections, since we are operating at maximum capacity (maximum number exceeded), all the intervals were
+ *   selecting connections that should be pinged, otherwise will timeout. This is why the previously mentioned
+ *   shift will result in the timeout of these connections, causing the mentioned cascading effect.
+ *
+ *   This is expected behavior, and **it's not an issue**. The number of connections ProxySQL can ping is
+ *   mainly determined by the interval that defines `wait_timeout` in the MySQL server and
+ *   `ping_interval_server_msec`, which default value is `1000`. With reasonable values for these two
+ *   parameters this number is very high, even with extremely low values for `wait_timeout`, like
+ *   `num_threads=4,wait_timeout=60,batch_size=64`, a large number of connections(`15104`) would still be
+ *   maintained without issues. This is what makes this issue an artificial one.
  */
 
-/*
-NOTE: the parameters in this test are tuned in a way that if proxysql starts
-with only 1 worker thread, it is unlikely to ping all connections on time.
-See note on wait_timeout
-*/
-
 #include <string>
 #include <vector>
 #include <map>
 #include <utility>
-#include <iostream>
 
 #include <unistd.h>
 #include <string.h>
 #include <sys/resource.h>
 
+#include "mysql.h"
 #include "tap.h"
 #include "utils.h"
 #include "json.hpp"
@@ -39,49 +81,20 @@ using std::pair;
 
 using srv_cfg = vector<pair<string,int>>;
 
-int wait_timeout = 10;
+#define SESSIONS_FOR_CONNECTIONS_HANDLER 64
 
-#ifndef SESSIONS_FOR_CONNECTIONS_HANDLER
-#define SESSIONS_FOR_CONNECTIONS_HANDLER    64
-#endif
+// IMPORTANT: We **always** gives ourselves `1` second grace period. Depending on MySQL connection killing
+// policy for `wait_timeout`, connections could already be killed on the edge of the interval. Also, for extra
+// safety, we gave `1` extra second to avoid possible rounding errors on time computations within MySQL.
+uint32_t grace_period = 2;
+int wait_timeout = 10 + grace_period;
 
-// if only 1 worker thread is running, wait_timeout should be bigger
-// 1 worker thread : wait_timeout = 45
-// 4 worker threads : wait_timeout = 10
-int compute_wait_timeout(MYSQL *my_conn) {
-	int res = EXIT_SUCCESS;
-	res = mysql_query(my_conn, "SELECT @@mysql-threads");
-	if (res != EXIT_SUCCESS) {
-		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(my_conn));
-		res = EXIT_FAILURE;
-		return res;
-	}
-	MYSQL_RES* my_res = mysql_store_result(my_conn);
-	if (my_res == nullptr) {
-		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(my_conn));
-		res = EXIT_FAILURE;
-		return res;
-	}
+int max_pinged_conns(uint32_t num_threads, uint32_t ping_interval_server_msec, uint32_t wait_timeout) {
+	uint32_t ping_proc_batches = floor((wait_timeout- (grace_period+1))/float(ping_interval_server_msec/1000.0));
 
-	MYSQL_ROW row = mysql_fetch_row(my_res);
-	if (row == nullptr || row[0] == nullptr) {
-		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(my_conn));
-		res = EXIT_FAILURE;
-		return res;
-	} else {
-		const char *val = row[0];
-		diag("mysql-threads = %s", val);
-		if (strcmp(val,"1")==0) {
-			diag("Setting wait_timeout to 45 instead of 10");
-			wait_timeout = 45;
-		}
-	}
-	mysql_free_result(my_res);
-
-	return res;
+	return (num_threads * SESSIONS_FOR_CONNECTIONS_HANDLER) * ping_proc_batches;
 }
 
-
 int change_mysql_cfg(
 	const CommandLine& cl, const string& host, const string& port, const srv_cfg& new_srv_cfg, srv_cfg& out_old_srv_cfg
 ) {
@@ -233,7 +246,6 @@ int check_backend_conns(
 
 	// 2. Check that the connections remain steady for a period of time
 	MYSQL* admin = mysql_init(NULL);
-	vector<MYSQL*> svrs_conns {};
 
 	{
 		if (!mysql_real_connect(admin, cl.host, cl.admin_username, cl.admin_password, NULL, cl.admin_port, NULL, 0)) {
@@ -241,19 +253,6 @@ int check_backend_conns(
 			return EXIT_FAILURE;
 		}
 
-		for (const auto& svr_addr : svrs_addrs) {
-			MYSQL* mysql = mysql_init(NULL);
-
-//			if (!mysql_real_connect(mysql, svr_addr.first.c_str(), cl.username, cl.password, NULL, svr_addr.second, NULL, 0)) {
-			if (!mysql_real_connect(mysql, svr_addr.first.c_str(), cl.mysql_username, cl.mysql_password, NULL, svr_addr.second, NULL, 0)) {
-				fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(mysql));
-				res = EXIT_FAILURE;
-				goto cleanup;
-			}
-
-			svrs_conns.push_back(mysql);
-		}
-
 		sleep(5);
 
 		uint64_t exp_conn_count = test_params.init_batch_size + test_params.batch_size * test_params.its;
@@ -263,8 +262,8 @@ int check_backend_conns(
 		uint64_t act_proxy_free_conn_count = 0;
 		uint64_t act_proxy_used_conn_count = 0;
 
+		uint32_t intv = 5;
 		uint32_t total_wait_time = 40;
-		uint32_t intv = 10;
 		uint32_t total_checks = total_wait_time / intv;
 
 		for (uint32_t check_num = 0; check_num < total_checks; check_num++) {
@@ -272,12 +271,30 @@ int check_backend_conns(
 			act_mysql_conn_count = 0;
 
 			const string mysql_query_string {
-				"SELECT count(*) FROM information_schema.processlist WHERE"
+				"SELECT count(*) FROM INFORMATION_SCHEMA.PROCESSLIST WHERE"
 					" USER=\"" + string { cl.username } + "\""
 					//" USER=\"" + string { cl.username } + "\" and DB=\"backend_conn_ping_test\""
 					//" COMMAND=\"Sleep\" and USER=\"" + string { cl.username } + "\" and DB=\"backend_conn_ping_test\""
 			};
 			diag("Line:%d : Running: %s", __LINE__ , mysql_query_string.c_str());
+
+			vector<MYSQL*> svrs_conns {};
+
+			// Recreate the connections at each interval
+			for (const auto& svr_addr : svrs_addrs) {
+				const char* c_svr_addr { svr_addr.first.c_str() };
+
+				MYSQL* mysql = mysql_init(NULL);
+
+				if (!mysql_real_connect(mysql, c_svr_addr, cl.mysql_username, cl.mysql_password, NULL, svr_addr.second, NULL, 0)) {
+					fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(mysql));
+					res = EXIT_FAILURE;
+					goto cleanup;
+				}
+
+				svrs_conns.push_back(mysql);
+			}
+
 			for (MYSQL* mysql : svrs_conns) {
 				uint64_t tmp_mysql_conn_count = 0;
 
@@ -290,6 +307,10 @@ int check_backend_conns(
 				act_mysql_conn_count += tmp_mysql_conn_count;
 			}
 
+			for (MYSQL* mysql : svrs_conns) {
+				mysql_close(mysql);
+			}
+
 			const string srv_ports {
 				std::accumulate(std::begin(svrs_addrs), std::end(svrs_addrs), string {},
 					[](const string& s1, const svr_addr& addr) -> string {
@@ -342,12 +363,6 @@ int check_backend_conns(
 			diag("act_proxy_free_conn_count = %lu", act_proxy_free_conn_count);
 			diag("act_proxy_used_conn_count = %lu", act_proxy_used_conn_count);
 
-			if (
-				act_mysql_conn_count >= exp_conn_count ||
-				(act_proxy_free_conn_count + act_proxy_used_conn_count + SESSIONS_FOR_CONNECTIONS_HANDLER) >= exp_conn_count
-			) {
-				break;
-			}
 			if (intv) {
 				diag("Line:%d : Sleeping %d" , __LINE__ , intv);
 				sleep(intv);
@@ -357,9 +372,7 @@ int check_backend_conns(
 		ok(
 			q_res == EXIT_SUCCESS && act_mysql_conn_count >= ((float) exp_conn_count * 0.95) // allow 5% margin of error
 			&&
-			((act_proxy_free_conn_count + act_proxy_used_conn_count + SESSIONS_FOR_CONNECTIONS_HANDLER) >= exp_conn_count)
-			//&& act_mysql_conn_count == act_proxy_free_conn_count // they can't be equal
-			,
+			((act_proxy_free_conn_count + act_proxy_used_conn_count) >= exp_conn_count),
 			"Created server connections should be properly maintained (pinged) by ProxySQL:"
 			" { ExpConns: %ld, ActMySQLConns: %ld, ActProxyConns: %ld }",
 			exp_conn_count, act_mysql_conn_count, act_proxy_free_conn_count
@@ -390,9 +403,6 @@ int check_backend_conns(
 cleanup:
 
 	mysql_close(admin);
-	for (MYSQL* mysql : svrs_conns) {
-		mysql_close(mysql);
-	}
 
 	for (MYSQL* mysql : mysql_conns) {
 		mysql_close(mysql);
@@ -457,38 +467,65 @@ int main(int, char**) {
 	// Close no longer required connection
 	mysql_close(proxy_mysql);
 
-	MYSQL* proxy_admin = mysql_init(NULL);
-	if (!proxy_admin) {
-		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(proxy_admin));
+	MYSQL* admin = mysql_init(NULL);
+	if (!admin) {
+		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(admin));
 		return exit_status();
 	}
 
-	if (!mysql_real_connect(proxy_admin, cl.host, cl.admin_username, cl.admin_password, NULL, cl.admin_port, NULL, 0)) {
-		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(proxy_admin));
+	if (!mysql_real_connect(admin, cl.host, cl.admin_username, cl.admin_password, NULL, cl.admin_port, NULL, 0)) {
+		fprintf(stderr, "File %s, line %d, Error: %s\n", __FILE__, __LINE__, mysql_error(admin));
 		return exit_status();
 	}
 
-	if (compute_wait_timeout(proxy_admin) != EXIT_SUCCESS) {
-		return exit_status();
-	}
-
-	double intv = 5;
-	double b = 128;
 	double b_0 = 256;
+	double b = 128;
 	double freq = 1000;
-	double rate = 64 / ( freq / 1000 );
-	double conn_creation_intv = 30;
+	double rate = 64 / (freq / 1000);
 
-	double its = (conn_creation_intv - b_0/rate) / ( b / rate );
+	const char q_mysql_threads[] { "SELECT @@mysql-threads" };
+	ext_val_t<int32_t> ext_threads { mysql_query_ext_val(admin, q_mysql_threads, int32_t(0)) };
+
+	if (ext_threads.err != EXIT_SUCCESS) {
+		const string err { get_ext_val_err(admin, ext_threads) };
+		diag("Failed query   query:`%s`, err:`%s`", q_mysql_threads, err.c_str());
+		return EXIT_FAILURE;
+	}
+
+	// IMPORTANT-NOTE:
+	// Variable 'ping_interval_server_msec' isn't relevant because ProxySQL isn't under load. The relevant
+	// variable passes to be `mysql-poll_timeout`; with each timeout threads will process idle sessions. If we
+	// wished to extend this test with a dummy load on ProxySQL, this should be uncommented.
+	// ===================================================================================================
+	// const char q_ping_intv[] { "SELECT @@mysql-ping_interval_server_msec" };
+	const char q_ping_intv[] { "SELECT @@mysql-poll_timeout" };
+	// ===================================================================================================
+	ext_val_t<int32_t> ext_ping_intv { mysql_query_ext_val(admin, q_ping_intv, int32_t(0)) };
+
+	if (ext_ping_intv.err != EXIT_SUCCESS) {
+		const string err { get_ext_val_err(admin, ext_ping_intv) };
+		diag("Failed query   query:`%s`, err:`%s`", q_ping_intv, err.c_str());
+		return EXIT_FAILURE;
+	}
+
+	uint32_t max_conns = max_pinged_conns(ext_threads.val, 2000, wait_timeout);
+	uint32_t server_max_conns = max_conns + 1000;
+	double its = floor((max_conns - b_0) / b);
+
+	double conn_creation_intv = b_0/rate + (b/rate)*its;
 	double delay_s = conn_creation_intv / its;
 
+	diag("ProxySQL config   mysql_threads:%d, ping_intv:%d", ext_threads.val, ext_ping_intv.val);
+	diag("Selected test params   b_0:%lf, b:%lf, freq:%lf, rate:%lf", b_0, b, freq, rate);
+	diag("Computed test params   max_conns=%d, intv=%lf, its=%lf", max_conns, conn_creation_intv, its);
+
 	// Cleanup previous backend connections
 	diag("Cleaning up previous backend connections...");
-	MYSQL_QUERY(proxy_admin, "UPDATE mysql_servers SET max_connections=0");
-	MYSQL_QUERY(proxy_admin, "LOAD MYSQL SERVERS TO RUNTIME");
+	MYSQL_QUERY(admin, "UPDATE mysql_servers SET max_connections=0");
+	MYSQL_QUERY(admin, "LOAD MYSQL SERVERS TO RUNTIME");
 
 	// Wait for backend connection cleanup
-	int w_res = wait_target_backend_conns(proxy_admin, 0, 10);
+	int w_res = wait_target_backend_conns(admin, 0, 10);
 	if (w_res != EXIT_SUCCESS) {
 		if (w_res == -2) {
 			const char* err_msg = "'wait_target_backend_conns()' timed out";
@@ -499,12 +536,12 @@ int main(int, char**) {
 	}
 	diag("Setting mysql_servers config...");
 	{
-		string query = "UPDATE mysql_servers SET max_connections=2500";
+		string query { "UPDATE mysql_servers SET max_connections=" + std::to_string(server_max_conns) };
 		diag("Running: %s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		query = "LOAD MYSQL SERVERS TO RUNTIME";
 		diag("Running: %s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 	}
 
 	diag("Setting ProxySQL config...");
@@ -512,27 +549,30 @@ int main(int, char**) {
 		// Set the backend connections ping frequency
 		string query = string { "SET mysql-ping_interval_server_msec=" + std::to_string(freq) };
 		diag("%s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		// Make sure no connection cleanup takes place
 		query = "SET mysql-free_connections_pct=100";
 		diag("%s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		// Don't retry on failure
 		query = "SET mysql-query_retries_on_failure=0";
 		diag("%s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
+		query = "SET mysql-max_connections=" + std::to_string(server_max_conns*3);
+		diag("%s", query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		// Set a higher max_connection number for the servers
 		query = "LOAD MYSQL VARIABLES TO RUNTIME";
 		diag("%s", query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 	}
 	// Configure MySQL infra servers with: 'wait_timeout' and 'max_connections'
 	vector<pair<mysql_res_row, srv_cfg>> servers_old_configs {};
 
 	diag("Configure 'MYSQL' infra servers...");
 	{
-		MYSQL_QUERY(proxy_admin, "SELECT DISTINCT hostname, port FROM mysql_servers WHERE hostgroup_id IN (0,1)");
-		MYSQL_RES* my_servers_res = mysql_store_result(proxy_admin);
+		MYSQL_QUERY(admin, "SELECT DISTINCT hostname, port FROM mysql_servers WHERE hostgroup_id IN (0,1)");
+		MYSQL_RES* my_servers_res = mysql_store_result(admin);
 		vector<mysql_res_row> servers_rows = extract_mysql_rows(my_servers_res);
 		mysql_free_result(my_servers_res);
 
@@ -541,7 +581,7 @@ int main(int, char**) {
 			return exit_status();
 		}
 
-		srv_cfg new_srv_cfg { { "wait_timeout", wait_timeout }, { "max_connections", 2500 } };
+		srv_cfg new_srv_cfg { { "wait_timeout", wait_timeout }, { "max_connections", 5000 } };
 
 		for (const mysql_res_row& srv_row : servers_rows) {
 			srv_cfg old_srv_cfg {};
@@ -565,7 +605,11 @@ int main(int, char**) {
 	const string docker_mode = getenv("DOCKER_MODE");
 	if (docker_mode.find("dns") == docker_mode.size() - 3) {
 		s_server_test.assign({ { "mysql1.infra-mysql57", 3306 } });
-		m_server_test.assign({ { "mysql1.infra-mysql57", 3306 }, { "mysql2.infra-mysql57", 3306 }, { "mysql3.infra-mysql57", 3306 } });
+		m_server_test.assign({
+			{ "mysql1.infra-mysql57", 3306 },
+			{ "mysql2.infra-mysql57", 3306 },
+			{ "mysql3.infra-mysql57", 3306 }
+		});
 	} else {
 		s_server_test.assign({ { "127.0.0.1", 13306 } });
 		m_server_test.assign({ { "127.0.0.1", 13306 }, { "127.0.0.1", 13307 }, { "127.0.0.1", 13308 } });
@@ -584,12 +628,12 @@ int main(int, char**) {
 		diag("Cleaning up previous backend connections...");
 		string query = "UPDATE mysql_servers SET max_connections=0";
 		diag("Line:%d : Running: %s", __LINE__ , query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		query = "LOAD MYSQL SERVERS TO RUNTIME";
 		diag("Line:%d : Running: %s", __LINE__ , query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 
-		int w_res = wait_target_backend_conns(proxy_admin, 0, 10);
+		int w_res = wait_target_backend_conns(admin, 0, 10);
 		if (w_res != EXIT_SUCCESS) {
 			string err_msg {};
 			if (w_res == -2) {
@@ -600,12 +644,13 @@ int main(int, char**) {
 			fprintf(stderr, "File %s, line %d, Error: \"%s\"\n", __FILE__, __LINE__, err_msg.c_str());
 		}
 
-		query = "UPDATE mysql_servers SET max_connections=2500";
+		diag("Reconfiguring ProxySQL 'mysql_servers' after connection cleanup");
+		query = "UPDATE mysql_servers SET max_connections=" + std::to_string(server_max_conns);
 		diag("Line:%d : Running: %s", __LINE__ , query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 		query = "LOAD MYSQL SERVERS TO RUNTIME";
 		diag("Line:%d : Running: %s", __LINE__ , query.c_str());
-		MYSQL_QUERY(proxy_admin, query.c_str());
+		MYSQL_QUERY(admin, query.c_str());
 
 		if (w_res == EXIT_SUCCESS) {
 			diag("Performing 'check_backend_conns()' for servers: '%s'", nlohmann::json(m_server_test).dump().c_str());
@@ -634,7 +679,7 @@ int main(int, char**) {
 		}
 	}
 
-	mysql_close(proxy_admin);
+	mysql_close(admin);
 
 	return exit_status();
 }
