@@ -12,7 +12,7 @@
 #include <iostream>
 
 #include <mysql.h>
-#include <mysql/mysqld_error.h>
+#include "mysqld_error.h"
 
 #include "tap.h"
 #include "command_line.h"
