@@ -28,27 +28,6 @@
 using std::string;
 using std::vector;
 
-vector<vector<bool>> get_all_bin_vec(size_t tg_size) {
-	vector<vector<bool>> all_bin_strs {};
-	vector<bool> bin_vec(tg_size, 0);
-
-	for (size_t i = 0; i < tg_size; i++) {
-		if (i == 0) {
-			bin_vec[i] = 0;
-			for (const vector<bool> p : get_permutations(bin_vec)) {
-				all_bin_strs.push_back(p);
-			}
-		}
-
-		bin_vec[i] = 1;
-		for (const vector<bool> p : get_permutations(bin_vec)) {
-			all_bin_strs.push_back(p);
-		}
-	}
-
-	return all_bin_strs;
-}
-
 vector<conn_cnf_t> gen_all_configs(const string& ff_user) {
 	vector<vector<bool>> all_bin_vec { get_all_bin_vec(5) };
 	std::sort(all_bin_vec.begin(), all_bin_vec.end());
